]> git.kernelconcepts.de Git - karo-tx-linux.git/commitdiff
Merge branch 'for-linus' of git://git.kernel.org/pub/scm/linux/kernel/git/jikos/trivial
authorLinus Torvalds <torvalds@linux-foundation.org>
Wed, 8 Oct 2014 01:16:26 +0000 (21:16 -0400)
committerLinus Torvalds <torvalds@linux-foundation.org>
Wed, 8 Oct 2014 01:16:26 +0000 (21:16 -0400)
Pull "trivial tree" updates from Jiri Kosina:
 "Usual pile from trivial tree everyone is so eagerly waiting for"

* 'for-linus' of git://git.kernel.org/pub/scm/linux/kernel/git/jikos/trivial: (39 commits)
  Remove MN10300_PROC_MN2WS0038
  mei: fix comments
  treewide: Fix typos in Kconfig
  kprobes: update jprobe_example.c for do_fork() change
  Documentation: change "&" to "and" in Documentation/applying-patches.txt
  Documentation: remove obsolete pcmcia-cs from Changes
  Documentation: update links in Changes
  Documentation: Docbook: Fix generated DocBook/kernel-api.xml
  score: Remove GENERIC_HAS_IOMAP
  gpio: fix 'CONFIG_GPIO_IRQCHIP' comments
  tty: doc: Fix grammar in serial/tty
  dma-debug: modify check_for_stack output
  treewide: fix errors in printk
  genirq: fix reference in devm_request_threaded_irq comment
  treewide: fix synchronize_rcu() in comments
  checkstack.pl: port to AArch64
  doc: queue-sysfs: minor fixes
  init/do_mounts: better syntax description
  MIPS: fix comment spelling
  powerpc/simpleboot: fix comment
  ...

92 files changed:
Documentation/ABI/testing/sysfs-class-net
Documentation/Changes
Documentation/CodingStyle
Documentation/applying-patches.txt
Documentation/block/null_blk.txt
Documentation/block/queue-sysfs.txt
Documentation/devicetree/bindings/clock/arm-integrator.txt
Documentation/devicetree/bindings/crypto/fsl-sec6.txt
Documentation/devicetree/bindings/iio/adc/vf610-adc.txt
Documentation/devicetree/bindings/mfd/s2mps11.txt
Documentation/devicetree/bindings/mtd/gpmc-nand.txt
Documentation/devicetree/bindings/net/samsung-sxgbe.txt
Documentation/devicetree/bindings/net/stmmac.txt
Documentation/devicetree/bindings/pci/host-generic-pci.txt
Documentation/devicetree/bindings/phy/phy-bindings.txt
Documentation/devicetree/bindings/power_supply/charger-manager.txt
Documentation/devicetree/bindings/sound/st,sta350.txt
Documentation/devicetree/bindings/vendor-prefixes.txt
Documentation/devicetree/bindings/video/atmel,lcdc.txt
Documentation/devicetree/bindings/video/fsl,imx-fb.txt
Documentation/kmemleak.txt
Documentation/lockup-watchdogs.txt
Documentation/mips/AU1xxx_IDE.README
Documentation/serial/serial-rs485.txt
Documentation/serial/tty.txt
arch/blackfin/Kconfig
arch/blackfin/mach-common/ints-priority.c
arch/m68k/Kconfig.devices
arch/mips/cavium-octeon/Kconfig
arch/mips/lantiq/falcon/sysctrl.c
arch/mips/lantiq/xway/sysctrl.c
arch/mips/pci/pci-lantiq.c
arch/mn10300/Kconfig
arch/powerpc/boot/simpleboot.c
arch/powerpc/platforms/powernv/opal.c
arch/powerpc/platforms/pseries/hotplug-memory.c
arch/score/Kconfig
block/blk-core.c
block/genhd.c
drivers/block/paride/pcd.c
drivers/crypto/qat/qat_common/adf_ctl_drv.c
drivers/gpu/drm/i915/intel_bios.c
drivers/i2c/busses/Kconfig
drivers/i2c/busses/i2c-s3c2410.c
drivers/infiniband/hw/ocrdma/ocrdma_verbs.c
drivers/infiniband/hw/usnic/usnic_ib_qp_grp.c
drivers/irqchip/Kconfig
drivers/media/i2c/cx25840/cx25840-ir.c
drivers/media/pci/cx23885/cx23888-ir.c
drivers/media/usb/gspca/stv06xx/stv06xx_vv6410.c
drivers/misc/mei/pci-me.c
drivers/misc/mei/pci-txe.c
drivers/net/bonding/bond_sysfs_slave.c
drivers/net/ethernet/mellanox/mlx4/cmd.c
drivers/net/ethernet/qlogic/netxen/netxen_nic_hw.c
drivers/net/ethernet/qlogic/qlcnic/qlcnic_hw.c
drivers/net/ethernet/via/via-velocity.c
drivers/net/wireless/libertas/cfg.c
drivers/net/wireless/libertas_tf/main.c
drivers/platform/x86/Kconfig
drivers/scsi/aic7xxx/Kconfig.aic79xx
drivers/scsi/fnic/fnic_debugfs.c
drivers/scsi/fnic/fnic_trace.c
drivers/scsi/nsp32.c
drivers/scsi/pcmcia/nsp_cs.c
drivers/scsi/qla2xxx/qla_nx2.c
drivers/usb/host/Kconfig
drivers/video/backlight/88pm860x_bl.c
fs/btrfs/tree-log.c
fs/stack.c
include/linux/clk.h
include/linux/gpio/driver.h
include/linux/kfifo.h
include/linux/pagemap.h
include/linux/percpu-refcount.h
init/do_mounts.c
ipc/util.c
kernel/auditsc.c
kernel/irq/devres.c
lib/bitmap.c
lib/dma-debug.c
lib/idr.c
lib/rhashtable.c
lib/vsprintf.c
mm/filemap.c
net/mac802154/wpan.c
net/netfilter/ipset/ip_set_core.c
net/rds/af_rds.c
samples/kprobes/jprobe_example.c
scripts/checkstack.pl
scripts/sign-file
security/inode.c

index d322b0581194a64a3e9791ef7864d17a95cce985..e1b2e785bba80ea468e6da0a3b055f39a0fce9d8 100644 (file)
@@ -159,7 +159,7 @@ Description:
                lower-level interface protocol used. Ethernet devices will show
                a 'mtu' attribute value of 1500 unless changed.
 
-What:          /sys/calss/net/<iface>/netdev_group
+What:          /sys/class/net/<iface>/netdev_group
 Date:          January 2011
 KernelVersion: 2.6.39
 Contact:       netdev@vger.kernel.org
index 227bec88021e5e88b0d0dfb04d94f774119afbb1..1de131bb49fbfc9a48c25d118d78d52d0eab9842 100644 (file)
@@ -167,18 +167,11 @@ later is recommended, due to some significant improvements).
 PCMCIAutils
 -----------
 
-PCMCIAutils replaces pcmcia-cs (see below). It properly sets up
+PCMCIAutils replaces pcmcia-cs. It properly sets up
 PCMCIA sockets at system startup and loads the appropriate modules
 for 16-bit PCMCIA devices if the kernel is modularized and the hotplug
 subsystem is used.
 
-Pcmcia-cs
----------
-
-PCMCIA (PC Card) support is now partially implemented in the main
-kernel source. The "pcmciautils" package (see above) replaces pcmcia-cs
-for newest kernels.
-
 Quota-tools
 -----------
 
@@ -341,17 +334,13 @@ Pcmciautils
 -----------
 o  <ftp://ftp.kernel.org/pub/linux/utils/kernel/pcmcia/>
 
-Pcmcia-cs
----------
-o  <http://pcmcia-cs.sourceforge.net/>
-
 Quota-tools
 ----------
 o  <http://sourceforge.net/projects/linuxquota/>
 
 DocBook Stylesheets
 -------------------
-o  <http://nwalsh.com/docbook/dsssl/>
+o  <http://sourceforge.net/projects/docbook/files/docbook-dsssl/>
 
 XMLTO XSLT Frontend
 -------------------
@@ -359,11 +348,11 @@ o  <http://cyberelk.net/tim/xmlto/>
 
 Intel P6 microcode
 ------------------
-o  <http://www.urbanmyth.org/microcode/>
+o  <https://downloadcenter.intel.com/>
 
 udev
 ----
-o <http://www.kernel.org/pub/linux/utils/kernel/hotplug/udev.html>
+o <http://www.freedesktop.org/software/systemd/man/udev.html>
 
 FUSE
 ----
@@ -371,7 +360,7 @@ o <http://sourceforge.net/projects/fuse>
 
 mcelog
 ------
-o <ftp://ftp.kernel.org/pub/linux/utils/cpu/mce/>
+o <http://www.mcelog.org/>
 
 Networking
 **********
index 6b6bef31e956d19872639c283d7257b3b3aaf45a..3171822c22a5d4b41d15820398798da52b98a703 100644 (file)
@@ -675,7 +675,7 @@ the ones already enabled by DEBUG.
 Many subsystems have Kconfig debug options to turn on -DDEBUG in the
 corresponding Makefile; in other cases specific files #define DEBUG.  And
 when a debug message should be unconditionally printed, such as if it is
-already inside a debug-related #ifdef secton, printk(KERN_DEBUG ...) can be
+already inside a debug-related #ifdef section, printk(KERN_DEBUG ...) can be
 used.
 
 
index a083ba35d1adf8f0b6f676f468a21853be3ddf0e..77df55b0225ab331bb7268592fa5d18ed8f909c7 100644 (file)
@@ -94,7 +94,7 @@ Common errors when patching
 ---
  When patch applies a patch file it attempts to verify the sanity of the
 file in different ways.
-Checking that the file looks like a valid patch file & checking the code
+Checking that the file looks like a valid patch file and checking the code
 around the bits being modified matches the context provided in the patch are
 just two of the basic sanity checks patch does.
 
index b2830b4358956ea90651227ec0d3541ce0014c96..2f6c6ff7161d4e77f3ec8ffee998b19f53b18cf7 100644 (file)
@@ -42,7 +42,7 @@ nr_devices=[Number of devices]: Default: 2
   Number of block devices instantiated. They are instantiated as /dev/nullb0,
   etc.
 
-irq_mode=[0-2]: Default: 1-Soft-irq
+irqmode=[0-2]: Default: 1-Soft-irq
   The completion mode used for completing IOs to the block-layer.
 
   0: None.
@@ -53,7 +53,7 @@ irq_mode=[0-2]: Default: 1-Soft-irq
      completion.
 
 completion_nsec=[ns]: Default: 10.000ns
-  Combined with irq_mode=2 (timer). The time each completion event must wait.
+  Combined with irqmode=2 (timer). The time each completion event must wait.
 
 submit_queues=[0..nr_cpus]:
   The number of submission queues attached to the device driver. If unset, it
index 7d2d046c265fce8e23402fdebf75184ccd990814..3a29f8914df9cea8a27048960f3b8b489e8d3ce4 100644 (file)
@@ -11,7 +11,7 @@ read-write.
 
 add_random (RW)
 ----------------
-This file allows to trun off the disk entropy contribution. Default
+This file allows to turn off the disk entropy contribution. Default
 value of this file is '1'(on).
 
 discard_granularity (RO)
@@ -72,7 +72,7 @@ Maximum segment size of the device.
 
 minimum_io_size (RO)
 --------------------
-This is the smallest preferred io size reported by the device.
+This is the smallest preferred IO size reported by the device.
 
 nomerges (RW)
 -------------
@@ -98,7 +98,7 @@ regulated by nr_requests.
 
 optimal_io_size (RO)
 --------------------
-This is the optimal io size reported by the device.
+This is the optimal IO size reported by the device.
 
 physical_block_size (RO)
 ------------------------
index ecc69520bceaa11542e8b7905dc3a52e1dc754a5..11f5f95f571bef74a2f0166e353b840ffd2ff580 100644 (file)
@@ -1,6 +1,6 @@
 Clock bindings for ARM Integrator and Versatile Core Module clocks
 
-Auxilary Oscillator Clock
+Auxiliary Oscillator Clock
 
 This is a configurable clock fed from a 24 MHz chrystal,
 used for generating e.g. video clocks. It is located on the
index c0a20cd972e3d9950f8ef844fa93319665d8e38d..baf8a3c1b469fe76b3f7b854058c2f53fa5ff38c 100644 (file)
@@ -1,5 +1,5 @@
 SEC 6 is as Freescale's Cryptographic Accelerator and Assurance Module (CAAM).
-Currently Freescale powerpc chip C29X is embeded with SEC 6.
+Currently Freescale powerpc chip C29X is embedded with SEC 6.
 SEC 6 device tree binding include:
    -SEC 6 Node
    -Job Ring Node
index dcebff1928e181d8313527b02ab186e38f919887..1a4a43d5c9ea5a80b1676e61c45f2ae1fe783bae 100644 (file)
@@ -9,7 +9,7 @@ Required properties:
 - interrupts: Should contain the interrupt for the device
 - clocks: The clock is needed by the ADC controller, ADC clock source is ipg clock.
 - clock-names: Must contain "adc", matching entry in the clocks property.
-- vref-supply: The regulator supply ADC refrence voltage.
+- vref-supply: The regulator supply ADC reference voltage.
 
 Example:
 adc0: adc@4003b000 {
index ba2d7f0f9c5f77f81eb1692108018cbac3ad9299..0e4026a6cbbfc21bc40dd9e1f5596acc33416e2a 100644 (file)
@@ -47,7 +47,7 @@ sub-node should be of the format as listed below.
 
  regulator-ramp-delay for BUCKs = [6250/12500/25000(default)/50000] uV/us
 
- BUCK[2/3/4/6] supports disabling ramp delay on hardware, so explictly
+ BUCK[2/3/4/6] supports disabling ramp delay on hardware, so explicitly
  regulator-ramp-delay = <0> can be used for them to disable ramp delay.
  In the absence of the regulator-ramp-delay property, the default ramp
  delay will be used.
index ee654e95d8ad55c3b53259b9f087be596b6dc99a..fb733c4e1c116e76bea05e690bbd968fd66c8395 100644 (file)
@@ -110,8 +110,8 @@ on various other factors also like;
        Other factor which governs the selection of ecc-scheme is oob-size.
        Higher ECC schemes require more OOB/Spare area to store ECC syndrome,
        so the device should have enough free bytes available its OOB/Spare
-       area to accomodate ECC for entire page. In general following expression
-       helps in determining if given device can accomodate ECC syndrome:
+       area to accommodate ECC for entire page. In general following expression
+       helps in determining if given device can accommodate ECC syndrome:
        "2 + (PAGESIZE / 512) * ECC_BYTES" >= OOBSIZE"
        where
                OOBSIZE         number of bytes in OOB/spare area
@@ -133,5 +133,5 @@ on various other factors also like;
        Example(b): For a device with PAGESIZE = 2048 and OOBSIZE = 128 and
                trying to use BCH16 (ECC_BYTES=26) ecc-scheme.
                Number of ECC bytes per page = (2 + (2048 / 512) * 26) = 106 B
-               which can be accomodate in the OOB/Spare area of this device
+               which can be accommodated in the OOB/Spare area of this device
                (OOBSIZE=128). So this device can use BCH16 ecc-scheme.
index 989f6c95cfd52510535167142b1a00f2a7b5630c..888c250197fe2b936bbcf9c4478482b4ed7601e2 100644 (file)
@@ -17,7 +17,7 @@ Required properties:
 - samsung,pbl: Integer, Programmable Burst Length.
   Supported values are 1, 2, 4, 8, 16, or 32.
 - samsung,burst-map: Integer, Program the possible bursts supported by sxgbe
-  This is an interger and represents allowable DMA bursts when fixed burst.
+  This is an integer and represents allowable DMA bursts when fixed burst.
   Allowable range is 0x01-0x3F. When this field is set fixed burst is enabled.
   When fixed length is needed for burst mode, it can be set within allowable
   range.
index e45ac3f926b164636b73e4280cf40ddfde314203..c41afd963edf508f36c57f125d092efc282c0429 100644 (file)
@@ -58,5 +58,5 @@ Examples:
                snps,multicast-filter-bins = <256>;
                snps,perfect-filter-entries = <128>;
                clocks = <&clock>;
-               clock-names = "stmmaceth">;
+               clock-names = "stmmaceth";
        };
index f0b0436807b48a7a5b074c7034c27a4d00513db6..cf3e205e0b7e0de18e8e6650bdc347d996807960 100644 (file)
@@ -55,7 +55,7 @@ For CAM, this 24-bit offset is:
         cfg_offset(bus, device, function, register) =
                    bus << 16 | device << 11 | function << 8 | register
 
-Whilst ECAM extends this by 4 bits to accomodate 4k of function space:
+Whilst ECAM extends this by 4 bits to accommodate 4k of function space:
 
         cfg_offset(bus, device, function, register) =
                    bus << 20 | device << 15 | function << 12 | register
index 2aa1840200edd43d42a450b6dad81c8709b2ff87..1293c321754c67014a4bdc4d4165ba517bac398d 100644 (file)
@@ -27,7 +27,7 @@ phys: phy {
 };
 
 That node describes an IP block (PHY provider) that implements 2 different PHYs.
-In order to differentiate between these 2 PHYs, an additonal specifier should be
+In order to differentiate between these 2 PHYs, an additional specifier should be
 given while trying to get a reference to it.
 
 PHY user node
index 2b33750e3db2a3016cc791982f72c87e90d3f2c9..ec4fe9de313735a8b15225da1f53889b67342829 100644 (file)
@@ -24,7 +24,7 @@ Optional properties :
  - cm-thermal-zone : name of external thermometer's thermal zone
  - cm-battery-* : threshold battery temperature for charging
        -cold : critical cold temperature of battery for charging
-       -cold-in-minus : flag that cold temerature is in minus degree
+       -cold-in-minus : flag that cold temperature is in minus degrees
        -hot : critical hot temperature of battery for charging
        -temp-diff : temperature difference to allow recharging
  - cm-dis/charging-max = limits of charging duration
index b7e71bf5caf4f3e32a359bea9b6a5997847e1552..307398ef2317d4a5f31937579a74c1409d1487df 100644 (file)
@@ -33,7 +33,7 @@ Optional properties:
        0: Channel 1
        1: Channel 2
        2: Channel 3
-       If parameter is missing, channel 1 is choosen.
+       If parameter is missing, channel 1 is chosen.
        This properties have to be specified as '/bits/ 8' values.
 
   -  st,thermal-warning-recover:
index 6073e76575eaa95e10fdbfff932c2a11250728c8..252e4e4c122af457c4d819a7852d18c0304cc838 100644 (file)
@@ -140,7 +140,7 @@ tlm Trusted Logic Mobility
 toradex        Toradex AG
 toshiba        Toshiba Corporation
 toumaz Toumaz
-usi    Universal Scientifc Industrial Co., Ltd.
+usi    Universal Scientific Industrial Co., Ltd.
 v3     V3 Semiconductor
 variscite      Variscite Ltd.
 via    VIA Technologies, Inc.
index b75af94a5e52c5a100470e1c0a98e093085f1fcd..7d0c4a1ab81181c300bb746ba4611a6d173364be 100644 (file)
@@ -39,8 +39,8 @@ Atmel LCDC Display
 -----------------------------------------------------
 Required properties (as per of_videomode_helper):
 
- - atmel,dmacon: dma controler configuration
- - atmel,lcdcon2: lcd controler configuration
+ - atmel,dmacon: dma controller configuration
+ - atmel,lcdcon2: lcd controller configuration
  - atmel,guard-time: lcd guard time (Delay in frame periods)
  - bits-per-pixel: lcd panel bit-depth.
 
index 0329f60d431e10ce5feb14878d654649d9767543..8c8c2f4e4c3fe3de0790b99a27643480a3ee4158 100644 (file)
@@ -20,7 +20,7 @@ Optional properties:
        register is not modified as recommended by the datasheet.
 - fsl,lpccr: Contrast Control Register value. This property provides the
        default value for the contrast control register.
-       If that property is ommited, the register is zeroed.
+       If that property is omitted, the register is zeroed.
 - fsl,lscr1: LCDC Sharp Configuration Register value.
 
 Example:
index b772418bf06486638a19781ef8cc5149c70ba4cc..f4f033c8d856e44ac85ba655da2348230acd8c4e 100644 (file)
@@ -122,7 +122,7 @@ Then as usual to get your report with:
 Freeing kmemleak internal objects
 ---------------------------------
 
-To allow access to previosuly found memory leaks after kmemleak has been
+To allow access to previously found memory leaks after kmemleak has been
 disabled by the user or due to an fatal error, internal kmemleak objects
 won't be freed when kmemleak is disabled, and those objects may occupy
 a large part of physical memory.
index d2a36602ca8d44591014712ed3c6c89c13cac8bc..ab0baa692c13be183e0ead6e67ecf9e70afc0dd1 100644 (file)
@@ -12,7 +12,7 @@ stack trace is displayed upon detection and, by default, the system
 will stay locked up. Alternatively, the kernel can be configured to
 panic; a sysctl, "kernel.softlockup_panic", a kernel parameter,
 "softlockup_panic" (see "Documentation/kernel-parameters.txt" for
-details), and a compile option, "BOOTPARAM_HARDLOCKUP_PANIC", are
+details), and a compile option, "BOOTPARAM_SOFTLOCKUP_PANIC", are
 provided for this.
 
 A 'hardlockup' is defined as a bug that causes the CPU to loop in
index cc887ecfd6eb364f58ac3f57f6b05cb760a623ea..52844a58cc8a73cc4d619c384e2d0016aa002b59 100644 (file)
@@ -2,7 +2,7 @@ README for MIPS AU1XXX IDE driver - Released 2005-07-15
 
 ABOUT
 -----
-This file describes the 'drivers/ide/mips/au1xxx-ide.c', related files and the
+This file describes the 'drivers/ide/au1xxx-ide.c', related files and the
 services they provide.
 
 If you are short in patience and just want to know how to add your hard disc to
index 41c8378c0b2fb9ee86d3a781e8aaff6cad33ff9a..39dac95422a3e57f0c0711ba8d67fd147cfea950 100644 (file)
 
 5. REFERENCES
 
- [1]   include/linux/serial.h
+ [1]   include/uapi/linux/serial.h
  [2]   Documentation/devicetree/bindings/serial/rs485.txt
index 540db41dfd5d7bdd0c3af757b34046e3e4617ea9..1e52d67d0abf5c8ccb86b6aa5d1170f509d73132 100644 (file)
@@ -146,7 +146,7 @@ set_termios()               Notify the tty driver that the device's termios
                        driver function is responsible for modifying any
                        bits in the request it cannot fulfill to indicate
                        the actual modes being used. A device with no
-                       hardware capability for change (eg a USB dongle or
+                       hardware capability for change (e.g. a USB dongle or
                        virtual port) can provide NULL for this method.
 
 throttle()             Notify the tty driver that input buffers for the
@@ -258,7 +258,7 @@ put_char()  -       Stuff a single character onto the queue. The
 
 flush_chars()  -       Ask the kernel to write put_char queue
 
-write_room()   -       Return the number of characters tht can be stuffed
+write_room()   -       Return the number of characters that can be stuffed
                        into the port buffers without overflow (or less).
                        The ldisc is responsible for being intelligent
                        about multi-threading of write_room/write calls
index ed30699cc6358fbc96793451c0897abec0e55b5a..af76634f8d9897fe61ae64a2b956d9ce07951c0c 100644 (file)
@@ -671,7 +671,7 @@ config TICKSOURCE_CORETMR
        default y
 endmenu
 
-menu "Clock souce"
+menu "Clock source"
        depends on GENERIC_CLOCKEVENTS
 config CYCLES_CLOCKSOURCE
        bool "CYCLES"
index 1f94784eab6d79b7f63673e20e2039fb41a07edb..694619365265a7792bb457c4fe48ebd484e53bca 100644 (file)
@@ -455,7 +455,7 @@ void handle_sec_sci_fault(uint32_t gstat)
                        printk(KERN_DEBUG "sec ack err\n");
                        break;
                default:
-                       printk(KERN_DEBUG "sec sci unknow err\n");
+                       printk(KERN_DEBUG "sec sci unknown err\n");
                }
        }
 
index d163991c571727bcda78a980d5910e74435b60be..2a74777667fd4871e23d8a90d61ffe33ac73f326 100644 (file)
@@ -73,7 +73,7 @@ config ATARI_ETHERNEC
          ROM port. The driver works by polling instead of interrupts, so it
          is quite slow.
 
-         This driver also suppports the ethernet part of the NetUSBee ROM
+         This driver also supports the ethernet part of the NetUSBee ROM
          port combined Ethernet/USB adapter.
 
          To compile the actual ethernet driver, choose Y or M in for the NE2000
index 6028666579381ba53c7d0c7f1c87ad6549bc4fdc..c370426a7322f9cca6ce50a03a5fec21fefe75d6 100644 (file)
@@ -1,7 +1,7 @@
 if CPU_CAVIUM_OCTEON
 
 config CAVIUM_CN63XXP1
-       bool "Enable CN63XXP1 errata worarounds"
+       bool "Enable CN63XXP1 errata workarounds"
        default "n"
        help
          The CN63XXP1 chip requires build time workarounds to
index 8f1866d8124d67b2fd3ba3f3a31063933b826d29..468ffa043607c602cfd7df3ac352e4e4029ecdad 100644 (file)
@@ -221,7 +221,7 @@ void __init ltq_soc_init(void)
                (request_mem_region(res_sys[2].start,
                                resource_size(&res_sys[2]),
                                res_sys[2].name) < 0))
-               pr_err("Failed to request core reources");
+               pr_err("Failed to request core resources");
 
        status_membase = ioremap_nocache(res_status.start,
                                        resource_size(&res_status));
index 51804b10a0360317392ebdbc902e59b8e7f4343d..2b15491de49462e27e71df6758a49efbd4b29ef4 100644 (file)
@@ -318,7 +318,7 @@ void __init ltq_soc_init(void)
                                res_cgu.name) < 0) ||
                (request_mem_region(res_ebu.start, resource_size(&res_ebu),
                                res_ebu.name) < 0))
-               pr_err("Failed to request core reources");
+               pr_err("Failed to request core resources");
 
        pmu_membase = ioremap_nocache(res_pmu.start, resource_size(&res_pmu));
        ltq_cgu_membase = ioremap_nocache(res_cgu.start,
index cb1ef9984069306dc8814f748581edca229f2c47..37fe8e7887e22ea417fc49ecf2eb96a324e425a8 100644 (file)
@@ -218,7 +218,7 @@ static int ltq_pci_probe(struct platform_device *pdev)
        res_cfg = platform_get_resource(pdev, IORESOURCE_MEM, 0);
        res_bridge = platform_get_resource(pdev, IORESOURCE_MEM, 1);
        if (!res_cfg || !res_bridge) {
-               dev_err(&pdev->dev, "missing memory reources\n");
+               dev_err(&pdev->dev, "missing memory resources\n");
                return -EINVAL;
        }
 
index a648de1b1096142d13d56055e10391bafe309ae5..4434b54e1d87c4e10e705ff5b7641d4f52c9616c 100644 (file)
@@ -181,7 +181,7 @@ endmenu
 config SMP
        bool "Symmetric multi-processing support"
        default y
-       depends on MN10300_PROC_MN2WS0038 || MN10300_PROC_MN2WS0050
+       depends on MN10300_PROC_MN2WS0050
        ---help---
          This enables support for systems with more than one CPU. If you have
          a system with only one CPU, say N. If you have a system with more
index 21cd48074ec8c61ae9bfb20424ea250ef1ffe6bb..9f8c678f0d9a52b3515b1b6cf5035950417f3ddc 100644 (file)
@@ -61,7 +61,7 @@ void platform_init(unsigned long r3, unsigned long r4, unsigned long r5,
                if (*reg++ != 0)
                        fatal("Memory range is not based at address 0\n");
 
-       /* get the memsize and trucate it to under 4G on 32 bit machines */
+       /* get the memsize and truncate it to under 4G on 32 bit machines */
        memsize64 = 0;
        for (i = 0; i < *ns; i++)
                memsize64 = (memsize64 << 32) | *reg++;
index b44eec3e8dbd8dbfb43873af73f006d20081b314..4b005ae5dc4b6cfb4c9a73c94b3debd3b3edc08d 100644 (file)
@@ -322,7 +322,7 @@ static void opal_handle_message(void)
 
        /* check for errors. */
        if (ret) {
-               pr_warning("%s: Failed to retrive opal message, err=%lld\n",
+               pr_warning("%s: Failed to retrieve opal message, err=%lld\n",
                                __func__, ret);
                return;
        }
index 17ee193960a09aab4e5e4502525f4b55788bdcce..34064f50945ef22a1246c8201556c7dc75a7cc8e 100644 (file)
@@ -126,7 +126,7 @@ static int pseries_remove_mem_node(struct device_node *np)
                return 0;
 
        /*
-        * Find the bae address and size of the memblock
+        * Find the base address and size of the memblock
         */
        regs = of_get_property(np, "reg", NULL);
        if (!regs)
@@ -200,7 +200,7 @@ static int pseries_update_drconf_memory(struct of_prop_reconfig *pr)
 
        /* The first int of the property is the number of lmb's described
         * by the property. This is followed by an array of of_drconf_cell
-        * entries. Get the niumber of entries and skip to the array of
+        * entries. Get the number of entries and skip to the array of
         * of_drconf_cell's.
         */
        entries = be32_to_cpu(*p++);
index 4ac8cae5727cf51a2e36750f9d4903a1b4b5af8c..366e1b599a7b7849b74f17f19308def9028cc971 100644 (file)
@@ -22,17 +22,14 @@ choice
 config ARCH_SCORE7
        bool "SCORE7 processor"
        select SYS_SUPPORTS_32BIT_KERNEL
-       select GENERIC_HAS_IOMAP
 
 config MACH_SPCT6600
        bool "SPCT6600 series based machines"
        select SYS_SUPPORTS_32BIT_KERNEL
-       select GENERIC_HAS_IOMAP
 
 config SCORE_SIM
        bool "Score simulator"
        select SYS_SUPPORTS_32BIT_KERNEL
-       select GENERIC_HAS_IOMAP
 endchoice
 
 endmenu
index bf930f481d437ac1b1731d32d453280309773445..9c888bd22b007c01d6b704115c4cf8b9a5a43833 100644 (file)
@@ -240,7 +240,7 @@ EXPORT_SYMBOL(blk_stop_queue);
  *     this function.
  *
  *     This function does not cancel any asynchronous activity arising
- *     out of elevator or throttling code. That would require elevaotor_exit()
+ *     out of elevator or throttling code. That would require elevator_exit()
  *     and blkcg_exit_queue() to be called with queue lock initialized.
  *
  */
@@ -933,7 +933,7 @@ static struct io_context *rq_ioc(struct bio *bio)
  * Get a free request from @q.  This function may fail under memory
  * pressure or if @q is dead.
  *
- * Must be callled with @q->queue_lock held and,
+ * Must be called with @q->queue_lock held and,
  * Returns %NULL on failure, with @q->queue_lock held.
  * Returns !%NULL on success, with @q->queue_lock *not held*.
  */
@@ -1110,7 +1110,7 @@ rq_starved:
  * Get a free request from @q.  If %__GFP_WAIT is set in @gfp_mask, this
  * function keeps retrying under memory pressure and fails iff @q is dead.
  *
- * Must be callled with @q->queue_lock held and,
+ * Must be called with @q->queue_lock held and,
  * Returns %NULL on failure, with @q->queue_lock held.
  * Returns !%NULL on success, with @q->queue_lock *not held*.
  */
@@ -1241,7 +1241,7 @@ struct request *blk_make_request(struct request_queue *q, struct bio *bio,
 EXPORT_SYMBOL(blk_make_request);
 
 /**
- * blk_rq_set_block_pc - initialize a requeest to type BLOCK_PC
+ * blk_rq_set_block_pc - initialize a request to type BLOCK_PC
  * @rq:                request to be initialized
  *
  */
index e6723bd4d7a16963da3367a1d4791c6402e78a82..bd3060684ab2f0cb3f0e926f6ac62071442709a7 100644 (file)
@@ -1545,7 +1545,7 @@ void disk_flush_events(struct gendisk *disk, unsigned int mask)
 /**
  * disk_clear_events - synchronously check, clear and return pending events
  * @disk: disk to fetch and clear events from
- * @mask: mask of events to be fetched and clearted
+ * @mask: mask of events to be fetched and cleared
  *
  * Disk events are synchronously checked and pending events in @mask
  * are cleared and returned.  This ignores the block count.
index 719cb1bc16401640a535ee1a0c3ae65de7f08e1c..3b7c9f1be484eb13b483ddc0e5f5f4794a9fe98b 100644 (file)
@@ -69,8 +69,8 @@
             nice        This parameter controls the driver's use of
                         idle CPU time, at the expense of some speed.
  
-       If this driver is built into the kernel, you can use kernel
-        the following command line parameters, with the same values
+       If this driver is built into the kernel, you can use the
+        following kernel command line parameters, with the same values
         as the corresponding module parameters listed above:
 
            pcd.drive0
index d97069b8a8e4937ce0d3bc057a2a833d43c581d5..6a92284a86b20c485764d327f1f9e7be70c78d9f 100644 (file)
@@ -436,7 +436,7 @@ static long adf_ctl_ioctl(struct file *fp, unsigned int cmd, unsigned long arg)
                ret = adf_ctl_ioctl_get_status(fp, cmd, arg);
                break;
        default:
-               pr_err("QAT: Invalid ioclt\n");
+               pr_err("QAT: Invalid ioctl\n");
                ret = -EFAULT;
                break;
        }
index eee79e1c322253165a4c58cff448fa401119abcd..afcc8dd40bdd437fa32c113d6aa966fb87bf3a1c 100644 (file)
@@ -946,7 +946,7 @@ static void parse_ddi_port(struct drm_i915_private *dev_priv, enum port port,
                DRM_DEBUG_KMS("Analog port %c is also DP or TMDS compatible\n",
                              port_name(port));
        if (is_dvi && (port == PORT_A || port == PORT_E))
-               DRM_DEBUG_KMS("Port %c is TMDS compabile\n", port_name(port));
+               DRM_DEBUG_KMS("Port %c is TMDS compatible\n", port_name(port));
        if (!is_dvi && !is_dp && !is_crt)
                DRM_DEBUG_KMS("Port %c is not DP/TMDS/CRT compatible\n",
                              port_name(port));
index 2ac87fa3058d5ec95cacb8e22c9a75bf5a9d8ee1..2e45ae3796f1bae03b685982608e8db23f6da54a 100644 (file)
@@ -357,7 +357,7 @@ config I2C_BCM_KONA
          If you say yes to this option, support will be included for the
          I2C interface on the Broadcom Kona family of processors.
 
-         If you do not need KONA I2C inteface, say N.
+         If you do not need KONA I2C interface, say N.
 
 config I2C_BLACKFIN_TWI
        tristate "Blackfin TWI I2C support"
index e086fb075f2b9999965a1933206853942180f7d5..e3b0337faeb7f0b9ac4fe44546974605e047b4a0 100644 (file)
@@ -244,7 +244,7 @@ static bool is_ack(struct s3c24xx_i2c *i2c)
                }
                usleep_range(1000, 2000);
        }
-       dev_err(i2c->dev, "ack was not recieved\n");
+       dev_err(i2c->dev, "ack was not received\n");
        return false;
 }
 
index 8f5f2577f28855eae258b278484a2bdda2eaf396..e8b8569788c0a69b557e5c352e518dcf5596dfe9 100644 (file)
@@ -1870,7 +1870,7 @@ static int ocrdma_build_inline_sges(struct ocrdma_qp *qp,
                hdr->total_len = ocrdma_sglist_len(wr->sg_list, wr->num_sge);
                if (unlikely(hdr->total_len > qp->max_inline_data)) {
                        pr_err("%s() supported_len=0x%x,\n"
-                              " unspported len req=0x%x\n", __func__,
+                              " unsupported len req=0x%x\n", __func__,
                                qp->max_inline_data, hdr->total_len);
                        return -EINVAL;
                }
index f8dfd76be89fbfdcb94559ed58cda9a3d8c591b2..db3588df3546b3ceaf8dce0ae8e175e6326265a3 100644 (file)
@@ -511,7 +511,7 @@ int usnic_ib_qp_grp_modify(struct usnic_ib_qp_grp *qp_grp,
                usnic_ib_qp_grp_state_to_string(old_state),
                usnic_ib_qp_grp_state_to_string(new_state));
        } else {
-               usnic_err("Failed to transistion %u from %s to %s",
+               usnic_err("Failed to transition %u from %s to %s",
                qp_grp->grp_id,
                usnic_ib_qp_grp_state_to_string(old_state),
                usnic_ib_qp_grp_state_to_string(new_state));
index b8632bf9a7f339dd8355f97867e1b39707e2a441..a31a9e40eed9389bcfb2e26a336a3093fb042496 100644 (file)
@@ -109,7 +109,7 @@ config XTENSA_MX
 config IRQ_CROSSBAR
        bool
        help
-         Support for a CROSSBAR ip that preceeds the main interrupt controller.
+         Support for a CROSSBAR ip that precedes the main interrupt controller.
          The primary irqchip invokes the crossbar's callback which inturn allocates
          a free irq and configures the IP. Thus the peripheral interrupts are
          routed to one of the free irqchip interrupt lines.
index e6588ee5bdb01e4e1a1333ba614e122fe7a194d8..4cf8f18bf097bc3bb4ff7795fe77a608fade090b 100644 (file)
@@ -224,7 +224,7 @@ static inline unsigned int lpf_count_to_us(unsigned int count)
 }
 
 /*
- * FIFO register pulse width count compuations
+ * FIFO register pulse width count computations
  */
 static u32 clock_divider_to_resolution(u16 divider)
 {
index 2c951dec2d33988688d53ffc82610119d3c99ec8..c2ff5fc01157c51e72ca2147a73f447f20be2e86 100644 (file)
@@ -263,7 +263,7 @@ static inline unsigned int lpf_count_to_us(unsigned int count)
 }
 
 /*
- * FIFO register pulse width count compuations
+ * FIFO register pulse width count computations
  */
 static u32 clock_divider_to_resolution(u16 divider)
 {
index e60cbb3aa60950675add7e332fe86cf53a847d39..f86cec091bf40f0e5700403152221a945d955d14 100644 (file)
@@ -259,7 +259,7 @@ static int vv6410_set_exposure(struct gspca_dev *gspca_dev, __s32 val)
        fine = val % VV6410_CIF_LINELENGTH;
        coarse = min(512, val / VV6410_CIF_LINELENGTH);
 
-       PDEBUG(D_CONF, "Set coarse exposure to %d, fine expsure to %d",
+       PDEBUG(D_CONF, "Set coarse exposure to %d, fine exposure to %d",
               coarse, fine);
 
        err = stv06xx_write_sensor(sd, VV6410_FINEH, fine >> 8);
index a0e9422b55a26aa9a6eb8b39b19f31bd3cfac549..959c313d84a73318820ac81f4c0b3cdf24f36300 100644 (file)
@@ -424,7 +424,7 @@ static int mei_me_pm_runtime_resume(struct device *device)
 }
 
 /**
- * mei_me_set_pm_domain - fill and set pm domian stucture for device
+ * mei_me_set_pm_domain - fill and set pm domain structure for device
  *
  * @dev: mei_device
  */
@@ -444,7 +444,7 @@ static inline void mei_me_set_pm_domain(struct mei_device *dev)
 }
 
 /**
- * mei_me_unset_pm_domain - clean pm domian stucture for device
+ * mei_me_unset_pm_domain - clean pm domain structure for device
  *
  * @dev: mei_device
  */
index 19de57368b7a2e8820bdef326663e4a0f9e40e50..74727dda51c1ba97de9464e0c0e433dfacea2e56 100644 (file)
@@ -371,7 +371,7 @@ static int mei_txe_pm_runtime_resume(struct device *device)
 }
 
 /**
- * mei_txe_set_pm_domain - fill and set pm domian stucture for device
+ * mei_txe_set_pm_domain - fill and set pm domain structure for device
  *
  * @dev: mei_device
  */
@@ -391,7 +391,7 @@ static inline void mei_txe_set_pm_domain(struct mei_device *dev)
 }
 
 /**
- * mei_txe_unset_pm_domain - clean pm domian stucture for device
+ * mei_txe_unset_pm_domain - clean pm domain structure for device
  *
  * @dev: mei_device
  */
index 5cd532ca1cfe60a3c9cc7db4833db50f97442a6c..b01b0ce4d1bef13d48c6f41c4e2e6a8f5d50e8d4 100644 (file)
@@ -36,7 +36,7 @@ static ssize_t state_show(struct slave *slave, char *buf)
        case BOND_STATE_BACKUP:
                return sprintf(buf, "backup\n");
        default:
-               return sprintf(buf, "UNKONWN\n");
+               return sprintf(buf, "UNKNOWN\n");
        }
 }
 static SLAVE_ATTR_RO(state);
index 02a2e90d581a450fcf02f19b1924de14d0cb60ea..923c4878461e8a1c1242034b618473efba584060 100644 (file)
@@ -1695,7 +1695,7 @@ static int mlx4_master_activate_admin_state(struct mlx4_priv *priv, int slave)
                        if (err) {
                                vp_oper->vlan_idx = NO_INDX;
                                mlx4_warn(&priv->dev,
-                                         "No vlan resorces slave %d, port %d\n",
+                                         "No vlan resources slave %d, port %d\n",
                                          slave, port);
                                return err;
                        }
@@ -1711,7 +1711,7 @@ static int mlx4_master_activate_admin_state(struct mlx4_priv *priv, int slave)
                                err = vp_oper->mac_idx;
                                vp_oper->mac_idx = NO_INDX;
                                mlx4_warn(&priv->dev,
-                                         "No mac resorces slave %d, port %d\n",
+                                         "No mac resources slave %d, port %d\n",
                                          slave, port);
                                return err;
                        }
index db4280ce9c09a9018401bd05b9193d5e7efee392..716fc37ada5a961677b577b0c693427ff8b32ee6 100644 (file)
@@ -922,7 +922,7 @@ int netxen_config_ipaddr(struct netxen_adapter *adapter, __be32 ip, int cmd)
 
        rv = netxen_send_cmd_descs(adapter, (struct cmd_desc_type0 *)&req, 1);
        if (rv != 0) {
-               printk(KERN_ERR "%s: could not notify %s IP 0x%x reuqest\n",
+               printk(KERN_ERR "%s: could not notify %s IP 0x%x request\n",
                                adapter->netdev->name,
                                (cmd == NX_IP_UP) ? "Add" : "Remove", ip);
        }
index 851cb4a80d50a6d4b2733ac2693fd799cca37885..03cd4c3d7835a855fca6796a252a6902031280bb 100644 (file)
@@ -941,7 +941,7 @@ void qlcnic_82xx_config_ipaddr(struct qlcnic_adapter *adapter,
        rv = qlcnic_send_cmd_descs(adapter, (struct cmd_desc_type0 *)&req, 1);
        if (rv != 0)
                dev_err(&adapter->netdev->dev,
-                               "could not notify %s IP 0x%x reuqest\n",
+                               "could not notify %s IP 0x%x request\n",
                                (cmd == QLCNIC_IP_UP) ? "Add" : "Remove", ip);
 }
 
index f5fbc12d3e101fb783d01ae1ed45bf9c91306814..a43e8492b1ce5a501694b1cc690fbd9d4a805b1a 100644 (file)
@@ -2056,7 +2056,7 @@ static int velocity_receive_frame(struct velocity_info *vptr, int idx)
        struct sk_buff *skb;
 
        if (rd->rdesc0.RSR & (RSR_STP | RSR_EDP)) {
-               VELOCITY_PRT(MSG_LEVEL_VERBOSE, KERN_ERR " %s : the received frame span multple RDs.\n", vptr->netdev->name);
+               VELOCITY_PRT(MSG_LEVEL_VERBOSE, KERN_ERR " %s : the received frame spans multiple RDs.\n", vptr->netdev->name);
                stats->rx_length_errors++;
                return -EINVAL;
        }
index 47a998d8f99e75bd5f59521a6593ca183cebb77a..40ab7f0b7be00a1a96b78884e534afa9fa55b3cb 100644 (file)
@@ -1353,7 +1353,7 @@ static int lbs_cfg_connect(struct wiphy *wiphy, struct net_device *dev,
                wait_event_interruptible_timeout(priv->scan_q,
                                                 (priv->scan_req == NULL),
                                                 (15 * HZ));
-               lbs_deb_assoc("assoc: scanning competed\n");
+               lbs_deb_assoc("assoc: scanning completed\n");
        }
 
        /* Find the BSS we want using available scan results */
index 088de9d25c39ecd4eb3dabc9177c72c3cd9619a4..25c5acc78bd141c218499eae06d1ed1c33f70e83 100644 (file)
@@ -332,7 +332,7 @@ static int lbtf_op_start(struct ieee80211_hw *hw)
 
 err_prog_firmware:
        priv->hw_reset_device(card);
-       lbtf_deb_leave_args(LBTF_DEB_MACOPS, "error programing fw; ret=%d", ret);
+       lbtf_deb_leave_args(LBTF_DEB_MACOPS, "error programming fw; ret=%d", ret);
        return ret;
 }
 
index 3bbcbf12c1fb7a88899762b417555b88ed08061d..4dcfb7116a0487656bf489a45c6345c18ea1e219 100644 (file)
@@ -540,7 +540,7 @@ config ASUS_NB_WMI
          This is a driver for newer Asus notebooks. It adds extra features
          like wireless radio and bluetooth control, leds, hotkeys, backlight...
 
-         For more informations, see
+         For more information, see
          <file:Documentation/ABI/testing/sysfs-platform-asus-wmi>
 
          If you have an ACPI-WMI compatible Asus Notebook, say Y or M
@@ -553,7 +553,7 @@ config EEEPC_WMI
          This is a driver for newer Eee PC laptops. It adds extra features
          like wireless radio and bluetooth control, leds, hotkeys, backlight...
 
-         For more informations, see
+         For more information, see
          <file:Documentation/ABI/testing/sysfs-platform-asus-wmi>
 
          If you have an ACPI-WMI compatible Eee PC laptop (>= 1000), say Y or M
index 6739069477dec7127191839cb1a90a604fef39cf..3b3d599103f86a619ef46b79f03ec9d01ba96eec 100644 (file)
@@ -70,7 +70,7 @@ config AIC79XX_DEBUG_MASK
        default "0"
        help
        Bit mask of debug options that is only valid if the
-       CONFIG_AIC79XX_DEBUG_ENBLE option is enabled.  The bits in this mask
+       CONFIG_AIC79XX_DEBUG_ENABLE option is enabled.  The bits in this mask
        are defined in the drivers/scsi/aic7xxx/aic79xx.h - search for the
        variable ahd_debug in that file to find them.
 
index 2c613bdea78f9b2ed400acb25ad5416a01674177..5980c10c734d27f702b59a7dd443771fa740d75f 100644 (file)
@@ -210,7 +210,7 @@ static ssize_t fnic_trace_ctrl_write(struct file *filp,
        else if (*trace_type == fc_trc_flag->fc_clear)
                fnic_fc_trace_cleared = val;
        else
-               pr_err("fnic: cannot write to any debufs file\n");
+               pr_err("fnic: cannot write to any debugfs file\n");
 
        (*ppos)++;
 
index c77285926827838d851114da691e09ec70ae3228..8b1b38751b4998dca420866c033b24cd4391b4c2 100644 (file)
@@ -592,7 +592,7 @@ int fnic_fc_trace_set_data(u32 host_no, u8 frame_type,
 
        if (fnic_fc_trace_cleared == 1) {
                fc_trace_entries.rd_idx = fc_trace_entries.wr_idx = 0;
-               pr_info("fnic: Reseting the read idx\n");
+               pr_info("fnic: Resetting the read idx\n");
                memset((void *)fnic_fc_ctlr_trace_buf_p, 0,
                                fnic_fc_trace_max_pages * PAGE_SIZE);
                fnic_fc_trace_cleared = 0;
index 50b086aef17836b75c82d428b990e938b3f23606..53284eb23a15e4d5d6e81c7bf5f3f7cf63934acf 100644 (file)
@@ -930,7 +930,7 @@ static int nsp32_queuecommand_lck(struct scsi_cmnd *SCpnt, void (*done)(struct s
 
        /* check target ID is not same as this initiator ID */
        if (scmd_id(SCpnt) == SCpnt->device->host->this_id) {
-               nsp32_dbg(NSP32_DEBUG_QUEUECOMMAND, "terget==host???");
+               nsp32_dbg(NSP32_DEBUG_QUEUECOMMAND, "target==host???");
                SCpnt->result = DID_BAD_TARGET << 16;
                done(SCpnt);
                return 0;
index 340ceff0382370a27880e7f376bd9357d70896ab..34aad32829f5a2ab01764ac1cd97e173a0a839b3 100644 (file)
@@ -533,7 +533,7 @@ static int nsp_negate_signal(struct scsi_cmnd *SCpnt, unsigned char mask,
        } while ((--time_out != 0) && (reg & mask) != 0);
 
        if (time_out == 0) {
-               nsp_msg(KERN_DEBUG, " %s signal off timeut", str);
+               nsp_msg(KERN_DEBUG, " %s signal off timeout", str);
        }
 
        return 0;
index da9e3902f2190b6a61d7f06200dbe5806f15dced..24a852828b5d726cac2c8d1378b0d664dd8b814a 100644 (file)
@@ -399,7 +399,7 @@ qla8044_idc_lock(struct qla_hw_data *ha)
                                 */
                                 ql_dbg(ql_dbg_p3p, vha, 0xb08a,
                                     "%s: IDC lock Recovery by %d "
-                                    "failed, Retrying timout\n", __func__,
+                                    "failed, Retrying timeout\n", __func__,
                                     ha->portnum);
                                 timeout = 0;
                        }
index 82800a775501bae2506d4ad259ca448c2926697c..56f4336ffa8656a1db10a7a756108e0b567dfd9b 100644 (file)
@@ -126,7 +126,7 @@ config XPS_USB_HCD_XILINX
        select USB_EHCI_BIG_ENDIAN_DESC
        select USB_EHCI_BIG_ENDIAN_MMIO
        ---help---
-               Xilinx xps USB host controller core is EHCI compilant and has
+               Xilinx xps USB host controller core is EHCI compliant and has
                transaction translator built-in. It can be configured to either
                support both high speed and full speed devices, or high speed
                devices only.
index 7db5234462d06a2c960ebf958fdddcae1f6db1f8..a6f7cc0a088352c9695196b442a2153e57abb662 100644 (file)
@@ -216,7 +216,7 @@ static int pm860x_backlight_probe(struct platform_device *pdev)
        data->reg_duty_cycle = res->start;
        res = platform_get_resource_byname(pdev, IORESOURCE_REG, "always on");
        if (!res) {
-               dev_err(&pdev->dev, "No REG resorce for always on\n");
+               dev_err(&pdev->dev, "No REG resource for always on\n");
                return -ENXIO;
        }
        data->reg_always_on = res->start;
index 1d1ba083ca6ecc1497bd1c141a431a2d5fa26cd9..d0262ceb85e10f2fe57237a9e3b52751c4012074 100644 (file)
@@ -3994,7 +3994,8 @@ again:
                if (ret < 0) {
                        err = ret;
                        goto out_unlock;
-               } if (ret) {
+               }
+               if (ret) {
                        ins_nr = 0;
                        btrfs_release_path(path);
                        continue;
index 5b5388250e29351a66b60cd7658832586eb80771..a54e33ed10f1beaeeb008e5b2dab1f6d9831c174 100644 (file)
@@ -44,7 +44,7 @@ void fsstack_copy_inode_size(struct inode *dst, struct inode *src)
         * include/linux/fs.h).  We don't necessarily hold i_mutex when this
         * is called, so take i_lock for that case.
         *
-        * And if CONFIG_LBADF (on 32-bit), continue our effort to keep the
+        * And if CONFIG_LBDAF (on 32-bit), continue our effort to keep the
         * two halves of i_blocks in sync despite SMP or PREEMPT: use i_lock
         * for that case too, and do both at once by combining the tests.
         *
index fb5e097d8f72b07fb34e480bb817593284dccdd2..afb44bfaf8d1bec1c38346587ffad6c45e3b0dd9 100644 (file)
@@ -238,7 +238,7 @@ void clk_put(struct clk *clk);
 
 /**
  * devm_clk_put        - "free" a managed clock source
- * @dev: device used to acuqire the clock
+ * @dev: device used to acquire the clock
  * @clk: clock source acquired with devm_clk_get()
  *
  * Note: drivers must ensure that all clk_enable calls made on this
index e78a2373e37453776a3cec8d6e9d6aea93738f24..c5e41da20112e3a244d2cd9672b2bc5b7f703184 100644 (file)
@@ -105,7 +105,7 @@ struct gpio_chip {
 
 #ifdef CONFIG_GPIOLIB_IRQCHIP
        /*
-        * With CONFIG_GPIO_IRQCHIP we get an irqchip inside the gpiolib
+        * With CONFIG_GPIOLIB_IRQCHIP we get an irqchip inside the gpiolib
         * to handle IRQs for most practical cases.
         */
        struct irq_chip         *irqchip;
@@ -164,7 +164,7 @@ int gpiochip_irqchip_add(struct gpio_chip *gpiochip,
                irq_flow_handler_t handler,
                unsigned int type);
 
-#endif /* CONFIG_GPIO_IRQCHIP */
+#endif /* CONFIG_GPIOLIB_IRQCHIP */
 
 int gpiochip_request_own_desc(struct gpio_desc *desc, const char *label);
 void gpiochip_free_own_desc(struct gpio_desc *desc);
index 554fde3a3927fa0374cf92c2ef4eb611db1202e5..473b43678ad12ef360801ffd9e32594285efd41a 100644 (file)
@@ -722,7 +722,7 @@ __kfifo_uint_must_check_helper( \
 /**
  * kfifo_dma_out_finish - finish a DMA OUT operation
  * @fifo: address of the fifo to be used
- * @len: number of bytes transferrd
+ * @len: number of bytes transferred
  *
  * This macro finish a DMA OUT operation. The out counter will be updated by
  * the len parameter. No error checking will be done.
index 3df8c7db7a4ec64e65b0ece15ad03a5fd58ccb30..5ba1813337df0d93a880eb13395ff826edf79520 100644 (file)
@@ -96,7 +96,7 @@ static inline void mapping_set_gfp_mask(struct address_space *m, gfp_t mask)
 }
 
 /*
- * The page cache can done in larger chunks than
+ * The page cache can be done in larger chunks than
  * one page, because it allows for more efficient
  * throughput (it can then be mapped into user
  * space in smaller chunks for same flexibility).
index ef5894ca8e503d9171f74cce2f63298c703333d3..68a64f11ce0215e34f7e1e0fbeefd42c5e49b40c 100644 (file)
@@ -29,7 +29,7 @@
  * calls io_destroy() or the process exits.
  *
  * In the aio code, kill_ioctx() is called when we wish to destroy a kioctx; it
- * calls percpu_ref_kill(), then hlist_del_rcu() and sychronize_rcu() to remove
+ * calls percpu_ref_kill(), then hlist_del_rcu() and synchronize_rcu() to remove
  * the kioctx from the proccess's list of kioctxs - after that, there can't be
  * any new users of the kioctx (from lookup_ioctx()) and it's then safe to drop
  * the initial ref with percpu_ref_put().
index 82f22885c87e995c3d18f6a0080bf639d99d9331..9b3565c41502af7bd9198f9a378c3a5cc7562423 100644 (file)
@@ -182,7 +182,8 @@ done:
 /*
  *     Convert a name into device number.  We accept the following variants:
  *
- *     1) device number in hexadecimal represents itself
+ *     1) <hex_major><hex_minor> device number in hexadecimal represents itself
+ *         no leading 0x, for example b302.
  *     2) /dev/nfs represents Root_NFS (0xff)
  *     3) /dev/<disk_name> represents the device number of disk
  *     4) /dev/<disk_name><decimal> represents the device number
index 27d74e69fd579bbb4dd95b27593c2902df64c0a7..d73b7af581e23a87617c8e165d9561b76f8d2c0f 100644 (file)
@@ -309,7 +309,7 @@ int ipc_addid(struct ipc_ids *ids, struct kern_ipc_perm *new, int size)
 /**
  * ipcget_new -        create a new ipc object
  * @ns: ipc namespace
- * @ids: ipc identifer set
+ * @ids: ipc identifier set
  * @ops: the actual creation routine to call
  * @params: its parameters
  *
@@ -363,7 +363,7 @@ static int ipc_check_perms(struct ipc_namespace *ns,
 /**
  * ipcget_public - get an ipc object or create a new one
  * @ns: ipc namespace
- * @ids: ipc identifer set
+ * @ids: ipc identifier set
  * @ops: the actual creation routine to call
  * @params: its parameters
  *
@@ -669,7 +669,7 @@ out:
 
 /**
  * ipcget - Common sys_*get() code
- * @ns: namsepace
+ * @ns: namespace
  * @ids: ipc identifier set
  * @ops: operations to be called on ipc object creation, permission checks
  *       and further checks
index 21eae3c05ec09e4ce5e0d302f8a59d0475407aa9..7208c1df248d645227c90bbbece7c249d6db6de6 100644 (file)
@@ -2406,7 +2406,7 @@ int __audit_log_bprm_fcaps(struct linux_binprm *bprm,
  * @new: the new credentials
  * @old: the old (current) credentials
  *
- * Record the aguments userspace sent to sys_capset for later printing by the
+ * Record the arguments userspace sent to sys_capset for later printing by the
  * audit system if applicable
  */
 void __audit_log_capset(const struct cred *new, const struct cred *old)
index 1ef0606797c9c211b5b328aef7696a23b1eab652..d5d0f7345c54504ac7e03f14394f282c86614a92 100644 (file)
@@ -38,7 +38,7 @@ static int devm_irq_match(struct device *dev, void *res, void *data)
  *
  *     Except for the extra @dev argument, this function takes the
  *     same arguments and performs the same function as
- *     request_irq().  IRQs requested with this function will be
+ *     request_threaded_irq().  IRQs requested with this function will be
  *     automatically freed on driver detach.
  *
  *     If an IRQ allocated with this function needs to be freed
index 1e031f2c9aba1ba4f536147ef5a2adbc6954addb..cd250a2e14cb1381d256ef0590b63bfd653cb83d 100644 (file)
@@ -884,7 +884,7 @@ EXPORT_SYMBOL(bitmap_bitremap);
  * read it, you're overqualified for your current job.)
  *
  * In other words, @orig is mapped onto (surjectively) @dst,
- * using the the map { <n, m> | the n-th bit of @relmap is the
+ * using the map { <n, m> | the n-th bit of @relmap is the
  * m-th set bit of @relmap }.
  *
  * Any set bits in @orig above bit number W, where W is the
@@ -932,7 +932,7 @@ EXPORT_SYMBOL(bitmap_bitremap);
  *
  *  Further lets say we use the following code, invoking
  *  bitmap_fold() then bitmap_onto, as suggested above to
- *  avoid the possitility of an empty @dst result:
+ *  avoid the possibility of an empty @dst result:
  *
  *     unsigned long *tmp;     // a temporary bitmap's bits
  *
index 98f2d7e91a9114e5e124e42bef00d7935708e521..add80cc02dbe6adbdb19d9daf9ab7878fedf60e6 100644 (file)
@@ -1149,7 +1149,7 @@ static void check_unmap(struct dma_debug_entry *ref)
 static void check_for_stack(struct device *dev, void *addr)
 {
        if (object_is_on_stack(addr))
-               err_printk(dev, NULL, "DMA-API: device driver maps memory from"
+               err_printk(dev, NULL, "DMA-API: device driver maps memory from "
                                "stack [addr=%p]\n", addr);
 }
 
index 50be3fa9b657d95d786b02c70f507ab27807bbd3..e654aebd5f807decad9b6cdacf58e1978562badd 100644 (file)
--- a/lib/idr.c
+++ b/lib/idr.c
@@ -626,7 +626,7 @@ static void __idr_remove_all(struct idr *idp)
  * idr_destroy().
  *
  * A typical clean-up sequence for objects stored in an idr tree will use
- * idr_for_each() to free all objects, if necessay, then idr_destroy() to
+ * idr_for_each() to free all objects, if necessary, then idr_destroy() to
  * free up the id mappings and cached idr_layers.
  */
 void idr_destroy(struct idr *idp)
index 16d02639d3346c4924caa5b0257c500e66289064..3d2b4733f6cb7cf2fdca301d80f7d7bb0d6d61cc 100644 (file)
@@ -54,7 +54,7 @@ static u32 __hashfn(const struct rhashtable *ht, const void *key,
 
 /**
  * rhashtable_hashfn - compute hash for key of given length
- * @ht:                hash table to compuate for
+ * @ht:                hash table to compute for
  * @key:       pointer to key
  * @len:       length of key
  *
@@ -85,7 +85,7 @@ static u32 obj_hashfn(const struct rhashtable *ht, const void *ptr, u32 hsize)
 
 /**
  * rhashtable_obj_hashfn - compute hash for hashed object
- * @ht:                hash table to compuate for
+ * @ht:                hash table to compute for
  * @ptr:       pointer to hashed object
  *
  * Computes the hash value using the hash function `hashfn` respectively
index 6fe2c84eb055695ffb80e766bd2d6fda1005b315..ba3cd0a35640db2672970612fa644c3aab70633d 100644 (file)
@@ -1937,7 +1937,7 @@ EXPORT_SYMBOL(sprintf);
  * @args: Arguments for the format string
  *
  * The format follows C99 vsnprintf, except %n is ignored, and its argument
- * is skiped.
+ * is skipped.
  *
  * The return value is the number of words(32bits) which would be generated for
  * the given input.
index 90effcdf948d6c463afa817e277e7eae94b657a6..8554d20b3523eef2365a4d48185721be2960bcdf 100644 (file)
@@ -727,7 +727,7 @@ EXPORT_SYMBOL_GPL(add_page_wait_queue);
  *
  * Unlocks the page and wakes up sleepers in ___wait_on_page_locked().
  * Also wakes sleepers in wait_on_page_writeback() because the wakeup
- * mechananism between PageLocked pages and PageWriteback pages is shared.
+ * mechanism between PageLocked pages and PageWriteback pages is shared.
  * But that's OK - sleepers in wait_on_page_writeback() just go back to sleep.
  *
  * The mb is necessary to enforce ordering between the clear_bit and the read
index 547838822d5e9c0d7064d72e2dc3be1ff2c14e14..d593500ceb3c63af67d2679ee182c791a1e6bdad 100644 (file)
@@ -90,7 +90,7 @@ mac802154_wpan_ioctl(struct net_device *dev, struct ifreq *ifr, int cmd)
        }
        case SIOCSIFADDR:
                dev_warn(&dev->dev,
-                        "Using DEBUGing ioctl SIOCSIFADDR isn't recommened!\n");
+                        "Using DEBUGing ioctl SIOCSIFADDR isn't recommended!\n");
                if (sa->family != AF_IEEE802154 ||
                    sa->addr.addr_type != IEEE802154_ADDR_SHORT ||
                    sa->addr.pan_id == IEEE802154_PANID_BROADCAST ||
index ec8114fae50b297f56760c3ac22d378c31957cd4..5edbbe829495f771087946dab1893e112c213e2f 100644 (file)
@@ -478,7 +478,7 @@ ip_set_test(ip_set_id_t index, const struct sk_buff *skb,
 
        if (ret == -EAGAIN) {
                /* Type requests element to be completed */
-               pr_debug("element must be competed, ADD is triggered\n");
+               pr_debug("element must be completed, ADD is triggered\n");
                write_lock_bh(&set->lock);
                set->variant->kadt(set, skb, par, IPSET_ADD, opt);
                write_unlock_bh(&set->lock);
index 424ff622ab5f8e77dc69c7b54b98bdaafa350329..10443377fb9d8f5b5cb928647fa58c03001a072b 100644 (file)
@@ -83,7 +83,7 @@ static int rds_release(struct socket *sock)
 
        /*
         * the binding lookup hash uses rcu, we need to
-        * make sure we sychronize_rcu before we free our
+        * make sure we synchronize_rcu before we free our
         * entry
         */
        rds_remove_bound(rs);
index b7541355b92bd547c27faa21ac6a01a2b96cbc85..9119ac6a82702972d5973c0da0a1e9399d665b8a 100644 (file)
 
 /* Proxy routine having the same arguments as actual do_fork() routine */
 static long jdo_fork(unsigned long clone_flags, unsigned long stack_start,
-             struct pt_regs *regs, unsigned long stack_size,
-             int __user *parent_tidptr, int __user *child_tidptr)
+             unsigned long stack_size, int __user *parent_tidptr,
+             int __user *child_tidptr)
 {
-       printk(KERN_INFO "jprobe: clone_flags = 0x%lx, stack_size = 0x%lx,"
-                       " regs = 0x%p\n",
-              clone_flags, stack_size, regs);
+       pr_info("jprobe: clone_flags = 0x%lx, stack_start = 0x%lx "
+               "stack_size = 0x%lx\n", clone_flags, stack_start, stack_size);
 
        /* Always end with a call to jprobe_return(). */
        jprobe_return();
index 899b4230320e0f8e032ddedbd0eaff6add225f30..dd8397894d5c7792431a3d1933f0e560d685489c 100755 (executable)
@@ -13,7 +13,7 @@
 #      Random bits by Matt Mackall <mpm@selenic.com>
 #      M68k port by Geert Uytterhoeven and Andreas Schwab
 #      AVR32 port by Haavard Skinnemoen (Atmel)
#      PARISC port by Kyle McMartin <kyle@parisc-linux.org>
 #      sparc port by Martin Habets <errandir_news@mph.eclipse.co.uk>
 #
 #      Usage:
@@ -45,7 +45,10 @@ my (@stack, $re, $dre, $x, $xs, $funcre);
        $x      = "[0-9a-f]";   # hex character
        $xs     = "[0-9a-f ]";  # hex character or space
        $funcre = qr/^$x* <(.*)>:$/;
-       if ($arch eq 'arm') {
+       if ($arch eq 'aarch64') {
+               #ffffffc0006325cc:       a9bb7bfd        stp     x29, x30, [sp,#-80]!
+               $re = qr/^.*stp.*sp,\#-([0-9]{1,8})\]\!/o;
+       } elsif ($arch eq 'arm') {
                #c0008ffc:      e24dd064        sub     sp, sp, #100    ; 0x64
                $re = qr/.*sub.*sp, sp, #(([0-9]{2}|[3-9])[0-9]{2})/o;
        } elsif ($arch eq 'avr32') {
index 2b7c4484d46cd5e28a9570fb3c8ff414213fff75..3906ee1e2f76ba585e95493f9bb063de1942915e 100755 (executable)
@@ -398,7 +398,7 @@ if ($verbose) {
     print "Size of signer's name  : ", length($signers_name), "\n";
     print "Size of key identifier : ", length($key_identifier), "\n";
     print "Size of signature      : ", length($signature), "\n";
-    print "Size of informaton     : ", length($info), "\n";
+    print "Size of information    : ", length($info), "\n";
     print "Size of magic number   : ", length($magic_number), "\n";
     print "Signer's name          : '", $signers_name, "'\n";
     print "Digest                 : $dgst\n";
index 43ce6e19015fc81e80786c26a07e2ac47e71109b..8e7ca62078abe85f988a90b796f265fc2172d526 100644 (file)
@@ -74,7 +74,7 @@ static struct file_system_type fs_type = {
  * pointer must be passed to the securityfs_remove() function when the file is
  * to be removed (no automatic cleanup happens if your module is unloaded,
  * you are responsible here).  If an error occurs, the function will return
- * the erorr value (via ERR_PTR).
+ * the error value (via ERR_PTR).
  *
  * If securityfs is not enabled in the kernel, the value %-ENODEV is
  * returned.
@@ -13,7 +13,7 @@
 #      M68k port by Geert Uytterhoeven and Andreas Schwab
 #      AVR32 port by Haavard Skinnemoen (Atmel)
-#      PARISC port by Kyle McMartin <kyle@parisc-linux.org>
+#      AArch64, PARISC ports by Kyle McMartin
 #      sparc port by Martin Habets <errandir_news@mph.eclipse.co.uk>
 #